/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.knox.gateway.cloud.idbroker.abfs;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.security.token.Token;
import org.apache.knox.gateway.cloud.idbroker.common.AbstractIDBTokenRenewer;
import org.apache.knox.gateway.cloud.idbroker.common.AbstractIDBTokenRenewerTest;
import org.easymock.EasyMock;

public class AbfsIDBTokenRenewerTest extends AbstractIDBTokenRenewerTest<AbfsIDBTokenIdentifier> {

  @Override
  protected Text getTokenKindForTest() {
    return AbfsIDBConstants.IDB_TOKEN_KIND;
  }

  @Override
  protected AbstractIDBTokenRenewer getTokenRenewerInstance() {
    return new AbfsIDBTokenRenewer();
  }

  @Override
  protected Configuration getConfiguration() {
    Configuration config = EasyMock.createNiceMock(Configuration.class);
    EasyMock.expect(config.get(AbfsIDBProperty.IDBROKER_GATEWAY.getPropertyName()))
            .andReturn("http://gateway:8444/gateway/") // dummy endpoint
            .anyTimes();
    EasyMock.expect(config.get(AbfsIDBProperty.IDBROKER_DT_PATH.getPropertyName()))
            .andReturn("dt")
            .anyTimes();
    EasyMock.replay(config);
    return config;
  }

  @Override
  protected Token<AbfsIDBTokenIdentifier> createTestToken(Text allowedRenewer) throws Exception {
    final AbfsIDBTokenIdentifier identifier = EasyMock.createNiceMock(AbfsIDBTokenIdentifier.class);
    EasyMock.expect(identifier.getKind()).andReturn(getTokenKindForTest()).anyTimes();
    EasyMock.expect(identifier.getRenewer()).andReturn(allowedRenewer).anyTimes();
    EasyMock.expect(identifier.getAccessToken()).andReturn("junkaccesstoken").anyTimes();
    EasyMock.expect(identifier.getExpiryTime()).andReturn(System.currentTimeMillis() + (60 * 1000)).anyTimes();
    EasyMock.replay(identifier);

    final Token<AbfsIDBTokenIdentifier> token = EasyMock.createNiceMock(Token.class);
    EasyMock.expect(token.decodeIdentifier()).andReturn(identifier).anyTimes();
    EasyMock.expect(token.getKind()).andReturn(getTokenKindForTest()).anyTimes();
    EasyMock.replay(token);

    return token;
  }

}
